==> nextcloud-29.0.9.tgz: nextcloud/apps/twofactor_totp/l10n/sc.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "As ativadu s'autenticatzione a duos fatores TOTP pro su contu tuo",
    "You disabled TOTP two-factor authentication for your account" : "As disativadu s'autenticatzione a duos fatores TOTP pro su contu tuo",
    "TOTP two-factor authentication disabled by an admin" : "Autenticatzione a duos fatores TOTP disativada dae s'amministratzione",
    "TOTP (Authenticator app)" : "TOTP (Aplicatzione autenticatzione)",
    "Authenticate with a TOTP app" : "Autentica·ti cun un'aplicatzione TOTP",
    "Two-Factor TOTP Provider" : "Frunidore TOTP a duos fatores",
    "TOTP two-factor provider" : "Frunidore a duos fatores pro TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Unu frunidore de autenticatzione a duos fatores pro TOTP (RFC 6238)",
    "Enable TOTP" : "Ativa TOTP",
    "Could not enable TOTP" : "No at fatu a ativare TOTP",
    "Could not verify your key. Please try again" : "No at fatu a verificare sa crae tua. Torra a proare",
    "Your new TOTP secret is:" : "Su segretu TOTP nou est:",
    "For quick setup, scan this QR code with your TOTP app:" : "Pro una cunfiguratzione lestra, iscansiona custu còdighe QR cun s'aplicatzione TOTP tua:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "A pustis de sa cunfiguratzione de s'aplicatzione, inserta unu còdighe de proa in fatu pro t'assegurare chi totu est funtzionende:",
    "Authentication code" : "Còdighe de autenticatzione",
    "Verify" : "Verìfica",
    "Get the authentication code from the two-factor authentication app on your device." : "Otene su còdighe de autenticatzione dae s'aplicatzione de autenticatzione a duos fatores in su dispositivu tuo.",
    "Submit" : "Imbia"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_totp/l10n/sc.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "As ativadu s'autenticatzione a duos fatores TOTP pro su contu tuo",
    "You disabled TOTP two-factor authentication for your account" : "As disativadu s'autenticatzione a duos fatores TOTP pro su contu tuo",
    "TOTP (Authenticator app)" : "TOTP (Aplicatzione autenticatzione)",
    "Authenticate with a TOTP app" : "Autentica·ti cun un'aplicatzione TOTP",
    "Two-Factor TOTP Provider" : "Frunidore TOTP a duos fatores",
    "Enable TOTP" : "Ativa TOTP",
    "Could not enable TOTP" : "No at fatu a ativare TOTP",
    "Could not verify your key. Please try again" : "No at fatu a verificare sa crae tua. Torra a proare",
    "Your new TOTP secret is:" : "Su segretu TOTP nou est:",
    "For quick setup, scan this QR code with your TOTP app:" : "Pro una cunfiguratzione lestra, iscansiona custu còdighe QR cun s'aplicatzione TOTP tua:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "A pustis de sa cunfiguratzione de s'aplicatzione, inserta unu còdighe de proa in fatu pro t'assegurare chi totu est funtzionende:",
    "Authentication code" : "Còdighe de autenticatzione",
    "Verify" : "Verìfica",
    "Get the authentication code from the two-factor authentication app on your device." : "Otene su còdighe de autenticatzione dae s'aplicatzione de autenticatzione a duos fatores in su dispositivu tuo.",
    "Submit" : "Imbia",
    "TOTP two-factor authentication disabled by an admin" : "Autenticatzione a duos fatores TOTP disativada dae s'amministratzione",
    "TOTP two-factor provider" : "Frunidore a duos fatores pro TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Unu frunidore de autenticatzione a duos fatores pro TOTP (RFC 6238)"
},
"nplurals=2; plural=(n != 1);");
